import { Client, isSuccess, delay, assertRes, ClientOptions, RetryOptions, ExtraResponse, Payload, RequestOptions, Response } from './client';
declare const authSrv: {
    /**
     * Checks user' session cookie.
     * @param cookie seesion cookie to check.
     * @param signature cookie' signature to check.
     * @param options request options.
     *
     * @returns a result with user info or a error that cookie is invalid.
     */
    checkUserCookie<T>(this: Client, cookie: string, signature: string, options?: RequestOptions | undefined): Promise<T>;
    /**
     * Checks user' access token.
     * @param accessToken access token to check.
     * @param options request options.
     *
     * @returns a result with user info or a error that access token is invalid.
     */
    checkUserToken<T_1>(this: Client, accessToken: string, options?: RequestOptions | undefined): Promise<T_1>;
    /**
     * Get a user by it's id.
     * @param _userId user's id.
     *
     * @returns a user info.
     */
    getUserById<T_2>(this: Client, _userId: string): Promise<T_2>;
    /**
     * Get a user by it's email.
     * @param email user's email.
     *
     * @returns a user info.
     */
    getUserByEmail<T_3>(this: Client, email: string): Promise<T_3>;
    /**
     * Get many users by their id.
     * @param ids a array of users's id.
     * @param queries a query of fieldmask.
     *
     * @returns a array of users info.
     */
    getUsersbyIds<T_4>(this: Client, ids: string[], queries?: object): Promise<T_4>;
};
/**
 * Auth client with some teambition auth service method.
 * It is a typical example that how to create custom service client with Client.
 * You may need to create your teambition web service client with some useful method.
 */
declare class TWS extends Client {
    readonly authSrv: Client & typeof authSrv;
    constructor(options: ClientOptions);
}
export default TWS;
export { TWS, Client, isSuccess, delay, assertRes, authSrv, ClientOptions, RetryOptions, ExtraResponse, Payload, RequestOptions, Response, };
