'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.authSrv = exports.assertRes = exports.delay = exports.isSuccess = exports.Client = exports.TWS = void 0;
const client_1 = require("./client");
Object.defineProperty(exports, "Client", { enumerable: true, get: function () { return client_1.Client; } });
Object.defineProperty(exports, "isSuccess", { enumerable: true, get: function () { return client_1.isSuccess; } });
Object.defineProperty(exports, "delay", { enumerable: true, get: function () { return client_1.delay; } });
Object.defineProperty(exports, "assertRes", { enumerable: true, get: function () { return client_1.assertRes; } });
const authSrv = {
    /**
     * Checks user' session cookie.
     * @param cookie seesion cookie to check.
     * @param signature cookie' signature to check.
     * @param options request options.
     *
     * @returns a result with user info or a error that cookie is invalid.
     */
    checkUserCookie(cookie, signature, options) {
        const client = options == null ? this : this.withOptions(options);
        return client.post('/v1/users/verify/cookie', { cookie, signed: signature });
    },
    /**
     * Checks user' access token.
     * @param accessToken access token to check.
     * @param options request options.
     *
     * @returns a result with user info or a error that access token is invalid.
     */
    checkUserToken(accessToken, options) {
        const client = options == null ? this : this.withOptions(options);
        return client.post('/v1/users/verify/token', { token: accessToken });
    },
    /**
     * Get a user by it's id.
     * @param _userId user's id.
     *
     * @returns a user info.
     */
    getUserById(_userId) {
        return this.get(`/v1/users/${_userId}`);
    },
    /**
     * Get a user by it's email.
     * @param email user's email.
     *
     * @returns a user info.
     */
    getUserByEmail(email) {
        return this.get('/v1/users:getByEmail', { email });
    },
    /**
     * Get many users by their id.
     * @param ids a array of users's id.
     * @param queries a query of fieldmask.
     *
     * @returns a array of users info.
     */
    getUsersbyIds(ids, queries = { fields: '_id,name,avatarUrl' }) {
        // queries 参数目前为 auth 的 fieldmask 功能做支持
        // 例： batchGetbyIds(['51762b8f78cfa9f357000011'], { fields: '_id' })
        return this.withQuery(queries).post(`/v1/users:BatchGetByIDs`, { ids });
    },
};
exports.authSrv = authSrv;
/**
 * Auth client with some teambition auth service method.
 * It is a typical example that how to create custom service client with Client.
 * You may need to create your teambition web service client with some useful method.
 */
class TWS extends client_1.Client {
    constructor(options) {
        super(options);
        this.authSrv = this.withService(authSrv);
    }
}
exports.TWS = TWS;
exports.default = TWS;
//# sourceMappingURL=index.js.map